@@ -128,7 +128,9 @@ task_table_emit_status_message (ETaskTable *task_table,
 }
 
 static gint
-task_table_percent_compare_cb (gconstpointer a, gconstpointer b, gpointer cmp_cache)
+task_table_percent_compare_cb (gconstpointer a,
+                               gconstpointer b,
+                               gpointer cmp_cache)
 {
 	gint percent1 = GPOINTER_TO_INT (a);
 	gint percent2 = GPOINTER_TO_INT (b);
@@ -137,7 +139,9 @@ task_table_percent_compare_cb (gconstpointer a, gconstpointer b, gpointer cmp_ca
 }
 
 static gint
-task_table_priority_compare_cb (gconstpointer a, gconstpointer b, gpointer cmp_cache)
+task_table_priority_compare_cb (gconstpointer a,
+                                gconstpointer b,
+                                gpointer cmp_cache)
 {
 	gint priority1, priority2;
 
@@ -155,7 +159,8 @@ task_table_priority_compare_cb (gconstpointer a, gconstpointer b, gpointer cmp_c
 }
 
 static const gchar *
-get_cache_str (gpointer cmp_cache, const gchar *str)
+get_cache_str (gpointer cmp_cache,
+               const gchar *str)
 {
 	const gchar *value;
 
@@ -175,7 +180,9 @@ get_cache_str (gpointer cmp_cache, const gchar *str)
 }
 
 static gboolean
-same_cache_string (gpointer cmp_cache, const gchar *str_a, const gchar *str_b)
+same_cache_string (gpointer cmp_cache,
+                   const gchar *str_a,
+                   const gchar *str_b)
 {
 	if (!cmp_cache)
 		return g_utf8_collate (str_a, str_b) == 0;
@@ -189,7 +196,9 @@ same_cache_string (gpointer cmp_cache, const gchar *str_a, const gchar *str_b)
 }
 
 static gint
-task_table_status_compare_cb (gconstpointer a, gconstpointer b, gpointer cmp_cache)
+task_table_status_compare_cb (gconstpointer a,
+                              gconstpointer b,
+                              gpointer cmp_cache)
 {
 	const gchar *string_a = a;
 	const gchar *string_b = b;
@@ -233,7 +242,7 @@ static void
 task_table_model_cal_view_progress_cb (ETaskTable *task_table,
                                        const gchar *message,
                                        gint progress,
-                                       ECalSourceType type)
+                                       ECalClientSourceType type)
 {
 	gdouble percent = (gdouble) progress;
 
@@ -241,10 +250,9 @@ task_table_model_cal_view_progress_cb (ETaskTable *task_table,
 }
 
 static void
-task_table_model_cal_view_complete_cb ( ETaskTable *task_table,
-					ECalendarStatus status,
-					const gchar *error_msg,
-					ECalSourceType type)
+task_table_model_cal_view_complete_cb (ETaskTable *task_table,
+                                       const GError *error,
+                                       ECalClientSourceType type)
 {
 	task_table_emit_status_message (task_table, NULL, -1.0);
 }
@@ -265,8 +273,10 @@ delete_selected_components (ETaskTable *task_table)
 		ECalModelComponent *comp_data = (ECalModelComponent *) l->data;
 		GError *error = NULL;
 
-		e_cal_remove_object (comp_data->client,
-				     icalcomponent_get_uid (comp_data->icalcomp), &error);
+		e_cal_client_remove_object_sync (
+			comp_data->client,
+			icalcomponent_get_uid (comp_data->icalcomp),
+			NULL, CALOBJ_MOD_THIS, NULL, &error);
 		delete_error_dialog (error, E_CAL_COMPONENT_TODO);
 		g_clear_error (&error);
 	}
@@ -501,7 +511,7 @@ task_table_constructed (GObject *object)
 
 	/* Priority field. */
 	cell = e_cell_text_new (NULL, GTK_JUSTIFY_LEFT);
-	g_object_set (G_OBJECT (cell),
+	g_object_set (cell,
 		      "strikeout_column", E_CAL_MODEL_TASKS_FIELD_STRIKEOUT,
 		      "bold_column", E_CAL_MODEL_TASKS_FIELD_OVERDUE,
 		      "bg_color_column", E_CAL_MODEL_FIELD_COLOR,
@@ -526,7 +536,7 @@ task_table_constructed (GObject *object)
 
 	/* Percent field. */
 	cell = e_cell_percent_new (NULL, GTK_JUSTIFY_LEFT);
-	g_object_set (G_OBJECT (cell),
+	g_object_set (cell,
 		      "strikeout_column", E_CAL_MODEL_TASKS_FIELD_STRIKEOUT,
 		      "bold_column", E_CAL_MODEL_TASKS_FIELD_OVERDUE,
 		      "bg_color_column", E_CAL_MODEL_FIELD_COLOR,
@@ -539,8 +549,8 @@ task_table_constructed (GObject *object)
 	strings = NULL;
 	for (percent = 0; percent <= 100; percent += 10) {
 		/* Translators: "%d%%" is the percentage of a task done.
-		   %d is the actual value, %% is replaced with a percent sign.
-		   Result values will be 0%, 10%, 20%, ... 100%
+		 * %d is the actual value, %% is replaced with a percent sign.
+		 * Result values will be 0%, 10%, 20%, ... 100%
 		*/
 		strings = g_list_append (strings, g_strdup_printf (_("%d%%"), percent));
 	}
@@ -555,7 +565,7 @@ task_table_constructed (GObject *object)
 
 	/* Transparency field. */
 	cell = e_cell_text_new (NULL, GTK_JUSTIFY_LEFT);
-	g_object_set (G_OBJECT (cell),
+	g_object_set (cell,
 		      "strikeout_column", E_CAL_MODEL_TASKS_FIELD_STRIKEOUT,
 		      "bold_column", E_CAL_MODEL_TASKS_FIELD_OVERDUE,
 		      "bg_color_column", E_CAL_MODEL_FIELD_COLOR,
@@ -578,7 +588,7 @@ task_table_constructed (GObject *object)
 
 	/* Status field. */
 	cell = e_cell_text_new (NULL, GTK_JUSTIFY_LEFT);
-	g_object_set (G_OBJECT (cell),
+	g_object_set (cell,
 		      "strikeout_column", E_CAL_MODEL_TASKS_FIELD_STRIKEOUT,
 		      "bold_column", E_CAL_MODEL_TASKS_FIELD_OVERDUE,
 		      "bg_color_column", E_CAL_MODEL_FIELD_COLOR,
@@ -769,6 +779,8 @@ task_table_query_tooltip (GtkWidget *widget,
 		gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
 		gtk_box_pack_start (GTK_BOX (w), l, FALSE, FALSE, 0);
 		g_free (tmp);
+
+		gtk_widget_modify_fg (l, GTK_STATE_NORMAL, &(style->text[GTK_STATE_NORMAL]));
 	}
 
 	e_cal_component_get_dtstart (new_comp, &dtstart);
@@ -782,8 +794,8 @@ task_table_query_tooltip (GtkWidget *widget,
 			e_cal_component_get_icalcomponent (new_comp),
 			dtstart.tzid);
 		if (!zone)
-			e_cal_get_timezone (
-				comp_data->client, dtstart.tzid, &zone, NULL);
+			e_cal_client_get_timezone_sync (
+				comp_data->client, dtstart.tzid, &zone, NULL, NULL);
 		if (!zone)
 			zone = default_zone;
 	} else {
@@ -829,6 +841,8 @@ task_table_query_tooltip (GtkWidget *widget,
 		l = gtk_label_new (tmp2->str);
 		gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
 		gtk_box_pack_start (GTK_BOX (w), l, FALSE, FALSE, 0);
+
+		gtk_widget_modify_fg (l, GTK_STATE_NORMAL, &(style->text[GTK_STATE_NORMAL]));
 	}
 
 	g_string_free (tmp2, TRUE);
@@ -845,6 +859,8 @@ task_table_query_tooltip (GtkWidget *widget,
 
 		g_free (tmp);
 		tmp = NULL;
+
+		gtk_widget_modify_fg (l, GTK_STATE_NORMAL, &(style->text[GTK_STATE_NORMAL]));
 	}
 
 	tmp2 = g_string_new ("");
@@ -868,7 +884,9 @@ task_table_query_tooltip (GtkWidget *widget,
 		l = gtk_label_new (tmp2->str);
 		gtk_label_set_line_wrap (GTK_LABEL (l), TRUE);
 		gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
-		gtk_box_pack_start (GTK_BOX (box), l, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (w), l, FALSE, FALSE, 0);
+
+		gtk_widget_modify_fg (l, GTK_STATE_NORMAL, &(style->text[GTK_STATE_NORMAL]));
 	}
 
 	g_string_free (tmp2, TRUE);
@@ -932,12 +950,11 @@ task_table_update_actions (ESelectable *selectable,
 	n_selected = e_table_selected_count (E_TABLE (task_table));
 
 	list = e_task_table_get_selected (task_table);
-	for (iter = list; iter != NULL; iter = iter->next) {
+	for (iter = list; iter != NULL && sources_are_editable; iter = iter->next) {
 		ECalModelComponent *comp_data = iter->data;
-		gboolean read_only;
 
-		e_cal_is_read_only (comp_data->client, &read_only, NULL);
-		sources_are_editable &= !read_only;
+		sources_are_editable = sources_are_editable &&
+			!e_client_is_readonly (E_CLIENT (comp_data->client));
 	}
 	g_slist_free (list);
 
@@ -990,7 +1007,8 @@ task_table_cut_clipboard (ESelectable *selectable)
 
 /* Helper for task_table_copy_clipboard() */
 static void
-copy_row_cb (gint model_row, gpointer data)
+copy_row_cb (gint model_row,
+             gpointer data)
 {
 	ETaskTable *task_table;
 	ECalModelComponent *comp_data;
@@ -1058,7 +1076,7 @@ clipboard_get_calendar_data (ETaskTable *task_table,
 	gchar *uid;
 	ECalComponent *comp;
 	ECalModel *model;
-	ECal *client;
+	ECalClient *client;
 	icalcomponent_kind kind;
 	const gchar *status_message;
 
@@ -1100,6 +1118,7 @@ clipboard_get_calendar_data (ETaskTable *task_table,
 			    child_kind == ICAL_VTODO_COMPONENT ||
 			    child_kind == ICAL_VJOURNAL_COMPONENT) {
 				ECalComponent *tmp_comp;
+				GError *error = NULL;
 
 				uid = e_cal_component_gen_uid ();
 				tmp_comp = e_cal_component_new ();
@@ -1107,31 +1126,49 @@ clipboard_get_calendar_data (ETaskTable *task_table,
 					tmp_comp,
 					icalcomponent_new_clone (subcomp));
 				e_cal_component_set_uid (tmp_comp, uid);
-				free (uid);
+				g_free (uid);
+				uid = NULL;
 
 				/* FIXME should we convert start/due/complete
 				 * times?  Also, need error handling. */
-				e_cal_create_object (
-					client, e_cal_component_get_icalcomponent (tmp_comp),
-					NULL, NULL);
+				if (!e_cal_client_create_object_sync (client, e_cal_component_get_icalcomponent (tmp_comp), &uid, NULL, &error))
+					uid = NULL;
+
+				if (error != NULL) {
+					g_warning (
+						"%s: Failed to create object: %s",
+						G_STRFUNC, error->message);
+					g_error_free (error);
+				}
 
 				g_object_unref (tmp_comp);
+				g_free (uid);
 			}
 			subcomp = icalcomponent_get_next_component (
 				vcal_comp, ICAL_ANY_COMPONENT);
 		}
 	} else {
+		GError *error = NULL;
+
 		comp = e_cal_component_new ();
 		e_cal_component_set_icalcomponent (comp, icalcomp);
 		uid = e_cal_component_gen_uid ();
 		e_cal_component_set_uid (comp, (const gchar *) uid);
-		free (uid);
+		g_free (uid);
+		uid = NULL;
 
-		e_cal_create_object (
-			client, e_cal_component_get_icalcomponent (comp),
-			NULL, NULL);
+		if (!e_cal_client_create_object_sync (client, e_cal_component_get_icalcomponent (comp), &uid, NULL, &error))
+			uid = NULL;
+
+		if (error != NULL) {
+			g_warning (
+				"%s: Failed to create object: %s",
+				G_STRFUNC, error->message);
+			g_error_free (error);
+		}
 
 		g_object_unref (comp);
+		g_free (uid);
 	}
 
 	task_table_emit_status_message (task_table, NULL, -1.0);
@@ -1182,7 +1219,8 @@ task_table_paste_clipboard (ESelectable *selectable)
  * gint pointed to by the closure data.
  */
 static void
-get_selected_row_cb (gint model_row, gpointer data)
+get_selected_row_cb (gint model_row,
+                     gpointer data)
 {
 	gint *row;
 
@@ -1213,7 +1251,8 @@ get_selected_comp (ETaskTable *task_table)
 }
 
 static void
-add_retract_data (ECalComponent *comp, const gchar *retract_comment)
+add_retract_data (ECalComponent *comp,
+                  const gchar *retract_comment)
 {
 	icalcomponent *icalcomp = NULL;
 	icalproperty *icalprop = NULL;
@@ -1228,7 +1267,8 @@ add_retract_data (ECalComponent *comp, const gchar *retract_comment)
 }
 
 static gboolean
-check_for_retract (ECalComponent *comp, ECal *client)
+check_for_retract (ECalComponent *comp,
+                   ECalClient *client)
 {
 	ECalComponentOrganizer org;
 	gchar *email = NULL;
@@ -1238,14 +1278,16 @@ check_for_retract (ECalComponent *comp, ECal *client)
 	if (!e_cal_component_has_attendees (comp))
 		return FALSE;
 
-	if (!e_cal_get_save_schedules (client))
+	if (!e_cal_client_check_save_schedules (client))
 		return FALSE;
 
 	e_cal_component_get_organizer (comp, &org);
 	strip = itip_strip_mailto (org.value);
 
-	ret_val =
-		e_cal_get_cal_address (client, &email, NULL) &&
+	ret_val = e_client_get_backend_property_sync (
+		E_CLIENT (client),
+		CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS,
+		&email, NULL, NULL) && email != NULL &&
 		g_ascii_strcasecmp (email, strip) == 0;
 
 	g_free (email);
@@ -1292,14 +1334,13 @@ task_table_delete_selection (ESelectable *selectable)
 			comp, &retract_comment,
 			GTK_WIDGET (task_table), &retract);
 		if (retract) {
-			GList *users = NULL;
+			GSList *users = NULL;
 			icalcomponent *icalcomp = NULL, *mod_comp = NULL;
 
 			add_retract_data (comp, retract_comment);
 			icalcomp = e_cal_component_get_icalcomponent (comp);
 			icalcomponent_set_method (icalcomp, ICAL_METHOD_CANCEL);
-			if (!e_cal_send_objects (comp_data->client, icalcomp, &users,
-						&mod_comp, &error))	{
+			if (!e_cal_client_send_objects_sync (comp_data->client, icalcomp, &users, &mod_comp, NULL, &error)) {
 				delete_error_dialog (error, E_CAL_COMPONENT_TODO);
 				g_clear_error (&error);
 				error = NULL;
@@ -1309,8 +1350,8 @@ task_table_delete_selection (ESelectable *selectable)
 					icalcomponent_free (mod_comp);
 
 				if (users) {
-					g_list_foreach (users, (GFunc) g_free, NULL);
-					g_list_free (users);
+					g_slist_foreach (users, (GFunc) g_free, NULL);
+					g_slist_free (users);
 				}
 			}
 
@@ -1539,7 +1580,8 @@ struct get_selected_uids_closure {
 
 /* Used from e_table_selected_row_foreach(), builds a list of the selected UIDs */
 static void
-add_uid_cb (gint model_row, gpointer data)
+add_uid_cb (gint model_row,
+            gpointer data)
 {
 	struct get_selected_uids_closure *closure = data;
 	ECalModelComponent *comp_data;
@@ -1596,17 +1638,25 @@ hide_completed_rows (ECalModel *model,
                      gchar *hide_sexp,
                      GPtrArray *comp_objects)
 {
-	GList *l, *m, *objects;
-	ECal *client;
+	GList *l;
+	GSList *m, *objects;
+	ECalClient *client;
 	gint pos;
 	gboolean changed = FALSE;
 
 	for (l = clients_list; l != NULL; l = l->next) {
+		GError *error = NULL;
+
 		client = l->data;
 
-		if (!e_cal_get_object_list (client, hide_sexp, &objects, NULL)) {
-			g_warning (G_STRLOC ": Could not get the objects");
+		e_cal_client_get_object_list_sync (
+			client, hide_sexp, &objects, NULL, &error);
 
+		if (error != NULL) {
+			g_warning (
+				"%s: Could not get the objects: %s",
+				G_STRFUNC, error->message);
+			g_error_free (error);
 			continue;
 		}
 
@@ -1635,8 +1685,8 @@ hide_completed_rows (ECalModel *model,
 			g_object_unref (comp);
 		}
 
-		g_list_foreach (objects, (GFunc) icalcomponent_free, NULL);
-		g_list_free (objects);
+		g_slist_foreach (objects, (GFunc) icalcomponent_free, NULL);
+		g_slist_free (objects);
 	}
 
 	if (changed) {
@@ -1652,15 +1702,23 @@ show_completed_rows (ECalModel *model,
                      gchar *show_sexp,
                      GPtrArray *comp_objects)
 {
-	GList *l, *m, *objects;
-	ECal *client;
+	GList *l;
+	GSList *m, *objects;
+	ECalClient *client;
 
 	for (l = clients_list; l != NULL; l = l->next) {
+		GError *error = NULL;
+
 		client = l->data;
 
-		if (!e_cal_get_object_list (client, show_sexp, &objects, NULL)) {
-			g_warning (G_STRLOC ": Could not get the objects");
+		e_cal_client_get_object_list_sync (
+			client, show_sexp, &objects, NULL, &error);
 
+		if (error != NULL) {
+			g_warning (
+				"%s: Could not get the objects: %s",
+				G_STRFUNC, error->message);
+			g_error_free (error);
 			continue;
 		}
 
@@ -1697,14 +1755,18 @@ show_completed_rows (ECalModel *model,
 			e_cal_component_free_id (id);
 			g_object_unref (comp);
 		}
+
+		g_slist_foreach (objects, (GFunc) icalcomponent_free, NULL);
+		g_slist_free (objects);
 	}
 }
 
 /* Returns the current time, for the ECellDateEdit items.
-   FIXME: Should probably use the timezone of the item rather than the
-   current timezone, though that may be difficult to get from here. */
+ * FIXME: Should probably use the timezone of the item rather than the
+ * current timezone, though that may be difficult to get from here. */
 static struct tm
-e_task_table_get_current_time (ECellDateEdit *ecde, gpointer data)
+e_task_table_get_current_time (ECellDateEdit *ecde,
+                               gpointer data)
 {
 	ETaskTable *task_table = data;
 	ECalModel *model;
