@@ -35,10 +35,6 @@
 #include "e-filter-rule.h"
 #include "e-rule-context.h"
 
-#define E_FILTER_RULE_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_FILTER_RULE, EFilterRulePrivate))
-
 typedef struct _FilterPartData FilterPartData;
 typedef struct _FilterRuleData FilterRuleData;
 
@@ -109,7 +105,7 @@ part_combobox_changed (GtkComboBox *combobox,
 		return;
 
 	/* here we do a widget shuffle, throw away the old widget/rulepart,
-	   and create another */
+	 * and create another */
 	if (data->partwidget)
 		gtk_container_remove (GTK_CONTAINER (data->container), data->partwidget);
 
@@ -120,7 +116,9 @@ part_combobox_changed (GtkComboBox *combobox,
 	data->part = newpart;
 	data->partwidget = e_filter_part_get_widget (newpart);
 	if (data->partwidget)
-		gtk_box_pack_start (GTK_BOX (data->container), data->partwidget, TRUE, TRUE, 0);
+		gtk_box_pack_start (
+			GTK_BOX (data->container),
+			data->partwidget, TRUE, TRUE, 0);
 }
 
 static GtkWidget *
@@ -205,7 +203,8 @@ less_parts (GtkWidget *button,
 static void
 attach_rule (GtkWidget *rule,
              FilterRuleData *data,
-             EFilterPart *part, gint row)
+             EFilterPart *part,
+             gint row)
 {
 	GtkWidget *remove;
 
@@ -480,7 +479,7 @@ filter_rule_xml_encode (EFilterRule *rule)
 		gchar *escaped = g_markup_escape_text (rule->name, -1);
 
 		work = xmlNewNode (NULL, (xmlChar *)"title");
-		xmlNodeSetContent (work, (xmlChar *)escaped);
+		xmlNodeSetContent (work, (xmlChar *) escaped);
 		xmlAddChild (node, work);
 
 		g_free (escaped);
@@ -559,7 +558,7 @@ filter_rule_xml_decode (EFilterRule *rule,
 			if (!rule->name) {
 				gchar *str, *decstr = NULL;
 
-				str = (gchar *)xmlNodeGetContent (work);
+				str = (gchar *) xmlNodeGetContent (work);
 				if (str) {
 					decstr = g_strdup (_(str));
 					xmlFree (str);
@@ -613,7 +612,8 @@ filter_rule_build_code (EFilterRule *rule,
 }
 
 static void
-filter_rule_copy (EFilterRule *dest, EFilterRule *src)
+filter_rule_copy (EFilterRule *dest,
+                  EFilterRule *src)
 {
 	GList *node;
 
@@ -660,12 +660,12 @@ filter_rule_get_widget (EFilterRule *rule,
 	gint rows, i;
 
 	/* this stuff should probably be a table, but the
-	   rule parts need to be a vbox */
+	 * rule parts need to be a vbox */
 	vbox = gtk_vbox_new (FALSE, 6);
 
 	label = gtk_label_new_with_mnemonic (_("R_ule name:"));
 	name = gtk_entry_new ();
-	gtk_label_set_mnemonic_widget ((GtkLabel *)label, name);
+	gtk_label_set_mnemonic_widget ((GtkLabel *) label, name);
 
 	if (!rule->name) {
 		rule->name = g_strdup (_("Untitled"));
@@ -725,13 +725,13 @@ filter_rule_get_widget (EFilterRule *rule,
 		label = gtk_label_new_with_mnemonic (_("_Find items:"));
 		combobox = gtk_combo_box_text_new ();
 
-		for (i=0;i<2;i++) {
+		for (i = 0; i < 2; i++) {
 			gtk_combo_box_text_append_text (
 				GTK_COMBO_BOX_TEXT (combobox),
 				_(thread_types[i]));
 		}
 
-		gtk_label_set_mnemonic_widget ((GtkLabel *)label, combobox);
+		gtk_label_set_mnemonic_widget ((GtkLabel *) label, combobox);
 		gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), rule->grouping);
 		gtk_widget_show (combobox);
 
@@ -758,16 +758,16 @@ filter_rule_get_widget (EFilterRule *rule,
 			N_("No reply or parent")
 		};
 
-		label = gtk_label_new_with_mnemonic (_("I_nclude threads"));
+		label = gtk_label_new_with_mnemonic (_("I_nclude threads:"));
 		combobox = gtk_combo_box_text_new ();
 
-		for (i=0;i<5;i++) {
+		for (i = 0; i < 5; i++) {
 			gtk_combo_box_text_append_text (
 				GTK_COMBO_BOX_TEXT (combobox),
 				_(thread_types[i]));
 		}
 
-		gtk_label_set_mnemonic_widget ((GtkLabel *)label, combobox);
+		gtk_label_set_mnemonic_widget ((GtkLabel *) label, combobox);
 		gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), rule->threading);
 		gtk_widget_show (combobox);
 
@@ -864,7 +864,8 @@ e_filter_rule_class_init (EFilterRuleClass *class)
 static void
 e_filter_rule_init (EFilterRule *rule)
 {
-	rule->priv = E_FILTER_RULE_GET_PRIVATE (rule);
+	rule->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		rule, E_TYPE_FILTER_RULE, EFilterRulePrivate);
 	rule->enabled = TRUE;
 }
 
@@ -1108,7 +1109,7 @@ e_filter_rule_next_list (GList *list,
 }
 
 EFilterRule *
-e_filter_rule_find_list (GList * list,
+e_filter_rule_find_list (GList *list,
                          const gchar *name,
                          const gchar *source)
 {
@@ -1120,7 +1121,8 @@ e_filter_rule_find_list (GList * list,
 		EFilterRule *rule = link->data;
 
 		if (strcmp (rule->name, name) == 0)
-			if (source == NULL || (rule->source != NULL && strcmp (rule->source, source) == 0))
+			if (source == NULL || (rule->source != NULL &&
+				strcmp (rule->source, source) == 0))
 				return rule;
 	}
 
