@@ -50,6 +50,9 @@
 #include <e-util/e-dialog-utils.h>
 #include <e-util/e-icon-factory.h>
 
+#include <shell/e-shell.h>
+#include <shell/e-shell-utils.h>
+
 #if defined (HAVE_NSS) && defined (ENABLE_SMIME)
 #include "certificate-viewer.h"
 #include "e-cert-db.h"
@@ -59,6 +62,7 @@
 #include "e-mail-attachment-bar.h"
 #include "em-format-html-display.h"
 #include "em-utils.h"
+#include "widgets/misc/e-attachment.h"
 #include "widgets/misc/e-attachment-button.h"
 #include "widgets/misc/e-attachment-view.h"
 
@@ -120,7 +124,7 @@ struct _attach_puri {
 	GtkWidget *forward, *down;
 	/* currently no way to correlate this data to the frame :( */
 	GtkHTML *frame;
-	guint shown:1;
+	guint shown : 1;
 
 	/* Embedded Frame */
 	GtkHTMLEmbedded *html;
@@ -189,7 +193,7 @@ efhd_xpkcs7mime_viewcert_clicked (GtkWidget *button,
 
 		/* oddly enough certificate_viewer_show doesn't ... */
 		gtk_widget_show (w);
-		g_signal_connect(w, "response", G_CALLBACK(gtk_widget_destroy), NULL);
+		g_signal_connect (w, "response", G_CALLBACK(gtk_widget_destroy), NULL);
 
 		if (w && po->widget)
 			gtk_window_set_transient_for ((GtkWindow *) w, (GtkWindow *) po->widget);
@@ -202,7 +206,7 @@ efhd_xpkcs7mime_viewcert_clicked (GtkWidget *button,
 #endif
 
 static void
-efhd_xpkcs7mime_add_cert_table (GtkWidget *vbox,
+efhd_xpkcs7mime_add_cert_table (GtkWidget *grid,
                                 CamelDList *certlist,
                                 struct _smime_pobject *po)
 {
@@ -232,12 +236,12 @@ efhd_xpkcs7mime_add_cert_table (GtkWidget *vbox,
 			w = gtk_label_new (l);
 			gtk_misc_set_alignment ((GtkMisc *) w, 0.0, 0.5);
 			g_free (la);
-			gtk_table_attach (table, w, 0, 1, n, n+1, GTK_FILL, GTK_FILL, 3, 3);
+			gtk_table_attach (table, w, 0, 1, n, n + 1, GTK_FILL, GTK_FILL, 3, 3);
 #if defined (HAVE_NSS) && defined (ENABLE_SMIME)
 			w = gtk_button_new_with_mnemonic(_("_View Certificate"));
-			gtk_table_attach (table, w, 1, 2, n, n+1, 0, 0, 3, 3);
+			gtk_table_attach (table, w, 1, 2, n, n + 1, 0, 0, 3, 3);
 			g_object_set_data((GObject *)w, "e-cert-info", info);
-			g_signal_connect(w, "clicked", G_CALLBACK(efhd_xpkcs7mime_viewcert_clicked), po);
+			g_signal_connect (w, "clicked", G_CALLBACK(efhd_xpkcs7mime_viewcert_clicked), po);
 
 			if (info->cert_data)
 				ec = e_cert_new (CERT_DupCertificate (info->cert_data));
@@ -248,7 +252,7 @@ efhd_xpkcs7mime_add_cert_table (GtkWidget *vbox,
 				g_object_unref (ec);
 #else
 			w = gtk_label_new (_("This certificate is not viewable"));
-			gtk_table_attach (table, w, 1, 2, n, n+1, 0, 0, 3, 3);
+			gtk_table_attach (table, w, 1, 2, n, n + 1, 0, 0, 3, 3);
 #endif
 			n++;
 		}
@@ -256,7 +260,7 @@ efhd_xpkcs7mime_add_cert_table (GtkWidget *vbox,
 		info = info->next;
 	}
 
-	gtk_box_pack_start ((GtkBox *) vbox, (GtkWidget *) table, TRUE, TRUE, 6);
+	gtk_container_add (GTK_CONTAINER (grid), GTK_WIDGET (table));
 }
 
 static void
@@ -265,7 +269,7 @@ efhd_xpkcs7mime_validity_clicked (GtkWidget *button,
 {
 	struct _smime_pobject *po = (struct _smime_pobject *) pobject;
 	GtkBuilder *builder;
-	GtkWidget *vbox, *w;
+	GtkWidget *grid, *w;
 
 	if (po->widget)
 		/* FIXME: window raise? */
@@ -276,11 +280,11 @@ efhd_xpkcs7mime_validity_clicked (GtkWidget *button,
 
 	po->widget = e_builder_get_widget(builder, "message_security_dialog");
 
-	vbox = e_builder_get_widget(builder, "signature_vbox");
+	grid = e_builder_get_widget(builder, "signature_grid");
 	w = gtk_label_new (_(smime_sign_table[po->valid->sign.status].description));
 	gtk_misc_set_alignment ((GtkMisc *) w, 0.0, 0.5);
 	gtk_label_set_line_wrap ((GtkLabel *) w, TRUE);
-	gtk_box_pack_start ((GtkBox *) vbox, w, TRUE, TRUE, 6);
+	gtk_container_add (GTK_CONTAINER (grid), w);
 	if (po->valid->sign.description) {
 		GtkTextBuffer *buffer;
 
@@ -290,6 +294,7 @@ efhd_xpkcs7mime_validity_clicked (GtkWidget *button,
 				 "hscrollbar_policy", GTK_POLICY_AUTOMATIC,
 				 "vscrollbar_policy", GTK_POLICY_AUTOMATIC,
 				 "shadow_type", GTK_SHADOW_IN,
+				 "expand", TRUE,
 				 "child", g_object_new(gtk_text_view_get_type(),
 						       "buffer", buffer,
 						       "cursor_visible", FALSE,
@@ -300,19 +305,19 @@ efhd_xpkcs7mime_validity_clicked (GtkWidget *button,
 				 NULL);
 		g_object_unref (buffer);
 
-		gtk_box_pack_start ((GtkBox *) vbox, w, TRUE, TRUE, 6);
+		gtk_container_add (GTK_CONTAINER (grid), w);
 	}
 
 	if (!camel_dlist_empty (&po->valid->sign.signers))
-		efhd_xpkcs7mime_add_cert_table (vbox, &po->valid->sign.signers, po);
+		efhd_xpkcs7mime_add_cert_table (grid, &po->valid->sign.signers, po);
 
-	gtk_widget_show_all (vbox);
+	gtk_widget_show_all (grid);
 
-	vbox = e_builder_get_widget(builder, "encryption_vbox");
+	grid = e_builder_get_widget(builder, "encryption_grid");
 	w = gtk_label_new (_(smime_encrypt_table[po->valid->encrypt.status].description));
 	gtk_misc_set_alignment ((GtkMisc *) w, 0.0, 0.5);
 	gtk_label_set_line_wrap ((GtkLabel *) w, TRUE);
-	gtk_box_pack_start ((GtkBox *) vbox, w, TRUE, TRUE, 6);
+	gtk_container_add (GTK_CONTAINER (grid), w);
 	if (po->valid->encrypt.description) {
 		GtkTextBuffer *buffer;
 
@@ -322,6 +327,7 @@ efhd_xpkcs7mime_validity_clicked (GtkWidget *button,
 				 "hscrollbar_policy", GTK_POLICY_AUTOMATIC,
 				 "vscrollbar_policy", GTK_POLICY_AUTOMATIC,
 				 "shadow_type", GTK_SHADOW_IN,
+				 "expand", TRUE,
 				 "child", g_object_new(gtk_text_view_get_type(),
 						       "buffer", buffer,
 						       "cursor_visible", FALSE,
@@ -332,17 +338,17 @@ efhd_xpkcs7mime_validity_clicked (GtkWidget *button,
 				 NULL);
 		g_object_unref (buffer);
 
-		gtk_box_pack_start ((GtkBox *) vbox, w, TRUE, TRUE, 6);
+		gtk_container_add (GTK_CONTAINER (grid), w);
 	}
 
 	if (!camel_dlist_empty (&po->valid->encrypt.encrypters))
-		efhd_xpkcs7mime_add_cert_table (vbox, &po->valid->encrypt.encrypters, po);
+		efhd_xpkcs7mime_add_cert_table (grid, &po->valid->encrypt.encrypters, po);
 
-	gtk_widget_show_all (vbox);
+	gtk_widget_show_all (grid);
 
 	g_object_unref (builder);
 
-	g_signal_connect(po->widget, "response", G_CALLBACK(efhd_xpkcs7mime_info_response), po);
+	g_signal_connect (po->widget, "response", G_CALLBACK(efhd_xpkcs7mime_info_response), po);
 	gtk_widget_show (po->widget);
 }
 
@@ -382,25 +388,35 @@ efhd_xpkcs7mime_button (EMFormatHTML *efh,
 }
 
 static gboolean
-remove_attachment_view_cb (gpointer message_part_id, gpointer attachment_view, gpointer gone_attachment_view)
+remove_attachment_view_cb (gpointer message_part_id,
+                           gpointer attachment_view,
+                           gpointer gone_attachment_view)
 {
 	return attachment_view == gone_attachment_view;
 }
 
 static void
-efhd_attachment_view_gone_cb (gpointer efh, GObject *gone_attachment_view)
+efhd_attachment_view_gone_cb (gpointer efh,
+                              GObject *gone_attachment_view)
 {
 	EMFormatHTMLDisplay *efhd = EM_FORMAT_HTML_DISPLAY (efh);
 
 	g_return_if_fail (efhd != NULL);
 
-	g_hash_table_foreach_remove (efhd->priv->attachment_views, remove_attachment_view_cb, gone_attachment_view);
+	g_hash_table_foreach_remove (
+		efhd->priv->attachment_views,
+		remove_attachment_view_cb,
+		gone_attachment_view);
 }
 
 static void
-weak_unref_attachment_view_cb (gpointer message_part_id, gpointer attachment_view, gpointer efh)
+weak_unref_attachment_view_cb (gpointer message_part_id,
+                               gpointer attachment_view,
+                               gpointer efh)
 {
-	g_object_weak_unref (G_OBJECT (attachment_view), efhd_attachment_view_gone_cb, efh);
+	g_object_weak_unref (
+		G_OBJECT (attachment_view),
+		efhd_attachment_view_gone_cb, efh);
 }
 
 static void
@@ -655,6 +671,153 @@ efhd_format_secure (EMFormat *emf,
 	}
 }
 
+static void
+attachment_load_finish (EAttachment *attachment,
+                        GAsyncResult *result,
+                        GFile *file)
+{
+	EShell *shell;
+	GtkWindow *parent;
+
+	e_attachment_load_finish (attachment, result, NULL);
+
+	shell = e_shell_get_default ();
+	parent = e_shell_get_active_window (shell);
+
+	e_attachment_save_async (
+		attachment, file, (GAsyncReadyCallback)
+		e_attachment_save_handle_error, parent);
+
+	g_object_unref (file);
+}
+
+static void
+action_image_save_cb (GtkAction *action,
+                      EMFormatHTMLDisplay *efhd)
+{
+	EWebView *web_view;
+	EMFormat *emf;
+	const gchar *image_src;
+	CamelMimePart *part;
+	EAttachment *attachment;
+	GFile *file;
+
+	web_view = em_format_html_get_web_view (EM_FORMAT_HTML (efhd));
+	g_return_if_fail (web_view != NULL);
+
+	image_src = e_web_view_get_cursor_image_src (web_view);
+	if (!image_src)
+		return;
+
+	emf = EM_FORMAT (efhd);
+	g_return_if_fail (emf != NULL);
+	g_return_if_fail (emf->message != NULL);
+
+	if (g_str_has_prefix (image_src, "cid:")) {
+		part = camel_mime_message_get_part_by_content_id (
+			emf->message, image_src + 4);
+		g_return_if_fail (part != NULL);
+
+		g_object_ref (part);
+	} else {
+		CamelStream *image_stream;
+		CamelDataWrapper *dw;
+		const gchar *filename;
+
+		image_stream = em_format_html_get_cached_image (
+			EM_FORMAT_HTML (efhd), image_src);
+		if (!image_stream)
+			return;
+
+		filename = strrchr (image_src, '/');
+		if (filename && strchr (filename, '?'))
+			filename = NULL;
+		else if (filename)
+			filename = filename + 1;
+
+		part = camel_mime_part_new ();
+		if (filename)
+			camel_mime_part_set_filename (part, filename);
+
+		dw = camel_data_wrapper_new ();
+		camel_data_wrapper_set_mime_type (
+			dw, "application/octet-stream");
+		camel_data_wrapper_construct_from_stream_sync (
+			dw, image_stream, NULL, NULL);
+		camel_medium_set_content (CAMEL_MEDIUM (part), dw);
+		g_object_unref (dw);
+
+		camel_mime_part_set_encoding (
+			part, CAMEL_TRANSFER_ENCODING_BASE64);
+
+		g_object_unref (image_stream);
+	}
+
+	file = e_shell_run_save_dialog (
+		e_shell_get_default (),
+		_("Save Image"), camel_mime_part_get_filename (part),
+		NULL, NULL, NULL);
+	if (file == NULL) {
+		g_object_unref (part);
+		return;
+	}
+
+	attachment = e_attachment_new ();
+	e_attachment_set_mime_part (attachment, part);
+
+	e_attachment_load_async (
+		attachment, (GAsyncReadyCallback)
+		attachment_load_finish, file);
+
+	g_object_unref (part);
+}
+
+static void
+efhd_web_view_update_actions_cb (EWebView *web_view,
+                                 EMFormatHTMLDisplay *efhd)
+{
+	const gchar *image_src;
+	gboolean visible;
+	GtkAction *action;
+
+	g_return_if_fail (web_view != NULL);
+
+	image_src = e_web_view_get_cursor_image_src (web_view);
+	visible = image_src && g_str_has_prefix (image_src, "cid:");
+	if (!visible && image_src) {
+		CamelStream *image_stream;
+
+		image_stream = em_format_html_get_cached_image (
+			EM_FORMAT_HTML (efhd), image_src);
+		visible = image_stream != NULL;
+
+		if (image_stream)
+			g_object_unref (image_stream);
+	}
+
+	action = e_web_view_get_action (web_view, "efhd-image-save");
+	if (action)
+		gtk_action_set_visible (action, visible);
+}
+
+static GtkActionEntry image_entries[] = {
+	{ "efhd-image-save",
+	  GTK_STOCK_SAVE,
+	  N_("Save _Image..."),
+	  NULL,
+	  N_("Save the image to a file"),
+	  G_CALLBACK (action_image_save_cb) }
+};
+
+static const gchar *image_ui =
+	"<ui>"
+	"  <popup name='context'>"
+	"    <placeholder name='custom-actions-2'>"
+	"      <menuitem action='efhd-image-save'/>"
+	"    </placeholder>"
+	"  </popup>"
+	"</ui>";
+
 static void
 efhd_finalize (GObject *object)
 {
@@ -664,11 +827,14 @@ efhd_finalize (GObject *object)
 	g_return_if_fail (efhd != NULL);
 
 	if (efhd->priv->attachment_views) {
-		g_hash_table_foreach (efhd->priv->attachment_views, weak_unref_attachment_view_cb, efhd);
+		g_hash_table_foreach (
+			efhd->priv->attachment_views,
+			weak_unref_attachment_view_cb, efhd);
 		g_hash_table_destroy (efhd->priv->attachment_views);
 		efhd->priv->attachment_views = NULL;
 	}
 
+	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -701,6 +867,9 @@ static void
 efhd_init (EMFormatHTMLDisplay *efhd)
 {
 	EWebView *web_view;
+	GtkActionGroup *image_actions;
+	GtkUIManager *ui_manager;
+	GError *error = NULL;
 
 	web_view = em_format_html_get_web_view (EM_FORMAT_HTML (efhd));
 
@@ -716,6 +885,25 @@ efhd_init (EMFormatHTMLDisplay *efhd)
 	EM_FORMAT_HTML (efhd)->text_html_flags |=
 		CAMEL_MIME_FILTER_TOHTML_CONVERT_URLS |
 		CAMEL_MIME_FILTER_TOHTML_CONVERT_ADDRESSES;
+
+	image_actions = e_web_view_get_action_group (web_view, "image");
+	g_return_if_fail (image_actions != NULL);
+
+	gtk_action_group_add_actions (
+		image_actions, image_entries,
+		G_N_ELEMENTS (image_entries), efhd);
+
+	/* Because we are loading from a hard-coded string, there is
+	 * no chance of I/O errors.  Failure here implies a malformed
+	 * UI definition.  Full stop. */
+	ui_manager = e_web_view_get_ui_manager (web_view);
+	gtk_ui_manager_add_ui_from_string (ui_manager, image_ui, -1, &error);
+	if (error != NULL)
+		g_error ("%s", error->message);
+
+	g_signal_connect (
+		web_view, "update-actions",
+		G_CALLBACK (efhd_web_view_update_actions_cb), efhd);
 }
 
 GType
@@ -930,7 +1118,9 @@ attachment_button_realized (GtkWidget *widget)
 
 /* attachment button callback */
 static gboolean
-efhd_attachment_button (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobject)
+efhd_attachment_button (EMFormatHTML *efh,
+                        GtkHTMLEmbedded *eb,
+                        EMFormatHTMLPObject *pobject)
 {
 	EMFormatHTMLDisplay *efhd = (EMFormatHTMLDisplay *) efh;
 	struct _attach_puri *info;
@@ -958,7 +1148,7 @@ efhd_attachment_button (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObj
 				size = ci->size;
 				/* what if its not encoded in base64 ? is it a case to consider? */
 				if (ci->encoding && !g_ascii_strcasecmp (ci->encoding, "base64"))
-					size = size/1.37;
+					size = size / 1.37;
 			}
 			camel_message_info_free (mi);
 		}
@@ -978,10 +1168,12 @@ efhd_attachment_button (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObj
 	e_attachment_set_can_show (attachment, info->handle != NULL);
 
 	web_view = em_format_html_get_web_view (efh);
+	g_return_val_if_fail (web_view != NULL, TRUE);
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (web_view));
 	parent = gtk_widget_is_toplevel (parent) ? parent : NULL;
 
 	view = em_format_html_display_get_attachment_view (efhd, info->attachment_view_part_id);
+	g_return_val_if_fail (view != NULL, TRUE);
 	gtk_widget_show (GTK_WIDGET (view));
 
 	store = e_attachment_view_get_store (view);
@@ -1018,7 +1210,7 @@ efhd_attachment_button (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObj
 	/* If the button is created, then give it focus after
 	 * it is realized, so that user can use arrow keys to scroll
 	 * message */
-	if (efhd->priv->attachment_expanded || e_attachment_button_get_expanded (E_ATTACHMENT_BUTTON (widget))) {
+	if (efhd->priv->attachment_expanded) {
 		g_signal_connect (
 			widget, "realize",
 			G_CALLBACK (attachment_button_realized), NULL);
@@ -1044,7 +1236,9 @@ efhd_attachment_frame (EMFormat *emf,
 }
 
 static void
-set_size_request_cb (gpointer message_part_id, gpointer widget, gpointer width)
+set_size_request_cb (gpointer message_part_id,
+                     gpointer widget,
+                     gpointer width)
 {
 	gtk_widget_set_size_request (widget, GPOINTER_TO_INT (width), -1);
 }
@@ -1133,7 +1327,8 @@ efhd_message_add_bar (EMFormat *emf,
 }
 
 static void
-efhd_optional_button_show (GtkWidget *widget, GtkWidget *w)
+efhd_optional_button_show (GtkWidget *widget,
+                           GtkWidget *w)
 {
 	GtkWidget *label = g_object_get_data (G_OBJECT (widget), "text-label");
 
@@ -1147,7 +1342,9 @@ efhd_optional_button_show (GtkWidget *widget, GtkWidget *w)
 }
 
 static void
-efhd_resize (GtkWidget *w, GtkAllocation *event, EMFormatHTML *efh)
+efhd_resize (GtkWidget *w,
+             GtkAllocation *event,
+             EMFormatHTML *efh)
 {
 	EWebView *web_view;
 	GtkAllocation allocation;
@@ -1159,7 +1356,9 @@ efhd_resize (GtkWidget *w, GtkAllocation *event, EMFormatHTML *efh)
 
 /* optional render attachment button callback */
 static gboolean
-efhd_attachment_optional (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobject)
+efhd_attachment_optional (EMFormatHTML *efh,
+                          GtkHTMLEmbedded *eb,
+                          EMFormatHTMLPObject *pobject)
 {
 	struct _attach_puri *info;
 	GtkWidget *hbox, *vbox, *button, *mainbox, *scroll, *label, *img;
@@ -1193,7 +1392,9 @@ efhd_attachment_optional (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPO
 	gtk_widget_show_all (hbox);
 	gtk_container_add (GTK_CONTAINER (button), GTK_WIDGET (hbox));
 	if (info->handle)
-		g_signal_connect(G_OBJECT (button), "clicked", G_CALLBACK(efhd_optional_button_show), scroll);
+		g_signal_connect (
+			button, "clicked",
+			G_CALLBACK (efhd_optional_button_show), scroll);
 	else {
 		gtk_widget_set_sensitive (button, FALSE);
 		gtk_widget_set_can_focus (button, FALSE);
@@ -1272,7 +1473,8 @@ efhd_free_attach_puri_data (EMFormatPURI *puri)
 
 /* returned object owned by html_display, thus do not unref it */
 EAttachmentView *
-em_format_html_display_get_attachment_view (EMFormatHTMLDisplay *html_display, const gchar *message_part_id)
+em_format_html_display_get_attachment_view (EMFormatHTMLDisplay *html_display,
+                                            const gchar *message_part_id)
 {
 	gpointer aview;
 
