@@ -29,17 +29,16 @@
 #include <libecal/e-cal-time-util.h>
 #include <libedataserver/e-categories.h>
 #include <libedataserver/e-sexp.h>
+#include <libedataserverui/e-client-utils.h>
 
-#include "e-util/e-binding.h"
 #include "e-util/e-dialog-utils.h"
 #include "e-util/e-file-utils.h"
-#include "e-util/e-error.h"
 #include "e-util/e-util.h"
 #include "e-util/gconf-bridge.h"
 #include "shell/e-shell-utils.h"
-#include "widgets/misc/e-popup-action.h"
+#include "misc/e-popup-action.h"
+#include "misc/e-selectable.h"
 
-#include "calendar/common/authentication.h"
 #include "calendar/gui/calendar-config.h"
 #include "calendar/gui/comp-util.h"
 #include "calendar/gui/e-cal-component-preview.h"
@@ -55,10 +54,6 @@
 #include "e-task-shell-sidebar.h"
 #include "e-task-shell-view-actions.h"
 
-#define E_TASK_SHELL_VIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_TASK_SHELL_VIEW, ETaskShellViewPrivate))
-
 /* Shorthand, requires a variable named "shell_window". */
 #define ACTION(name) \
 	(E_SHELL_WINDOW_ACTION_##name (shell_window))
