@@ -19,6 +19,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-mail-shell-backend.h"
 
 #include <glib/gi18n.h>
@@ -106,7 +110,7 @@ action_mail_folder_new_cb (GtkAction *action,
 {
 	EMFolderTree *folder_tree = NULL;
 	EMailShellSidebar *mail_shell_sidebar;
-	EMailSession *mail_session;
+	EMailBackend *backend;
 	EShellSidebar *shell_sidebar;
 	EShellView *shell_view;
 	const gchar *view_name;
@@ -114,19 +118,16 @@ action_mail_folder_new_cb (GtkAction *action,
 	/* Take care not to unnecessarily load the mail shell view. */
 	view_name = e_shell_window_get_active_view (shell_window);
 	if (g_strcmp0 (view_name, BACKEND_NAME) != 0) {
-		EShellBackend *mail_backend;
+		EShellBackend *shell_backend;
 		EShell *shell;
 
 		shell = e_shell_window_get_shell (shell_window);
 
-		mail_backend =
+		shell_backend =
 			e_shell_get_backend_by_name (shell, BACKEND_NAME);
-		g_return_if_fail (mail_backend != NULL);
+		g_return_if_fail (E_IS_MAIL_BACKEND (shell_backend));
 
-		mail_session =
-			e_mail_backend_get_session (
-			E_MAIL_BACKEND (mail_backend));
-		g_return_if_fail (mail_session != NULL);
+		backend = E_MAIL_BACKEND (shell_backend);
 
 		goto exit;
 	}
@@ -136,11 +137,11 @@ action_mail_folder_new_cb (GtkAction *action,
 
 	mail_shell_sidebar = E_MAIL_SHELL_SIDEBAR (shell_sidebar);
 	folder_tree = e_mail_shell_sidebar_get_folder_tree (mail_shell_sidebar);
-	mail_session = em_folder_tree_get_session (folder_tree);
+	backend = em_folder_tree_get_backend (folder_tree);
 
 exit:
 	em_folder_utils_create_folder (
-		GTK_WINDOW (shell_window), folder_tree, mail_session, NULL);
+		GTK_WINDOW (shell_window), backend, folder_tree, NULL);
 }
 
 static void
@@ -148,14 +149,14 @@ action_mail_message_new_cb (GtkAction *action,
                             EShellWindow *shell_window)
 {
 	EMailShellSidebar *mail_shell_sidebar;
-	EShellBackend *shell_backend;
 	EShellSidebar *shell_sidebar;
 	EShellView *shell_view;
 	EShell *shell;
 	EMFolderTree *folder_tree;
 	CamelFolder *folder = NULL;
+	CamelStore *store;
 	const gchar *view_name;
-	gchar *folder_uri = NULL;
+	gchar *folder_name;
 
 	shell = e_shell_window_get_shell (shell_window);
 
@@ -168,36 +169,19 @@ action_mail_message_new_cb (GtkAction *action,
 		goto exit;
 
 	shell_view = e_shell_window_get_shell_view (shell_window, view_name);
-	shell_backend = e_shell_view_get_shell_backend (shell_view);
 	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
 
 	mail_shell_sidebar = E_MAIL_SHELL_SIDEBAR (shell_sidebar);
 	folder_tree = e_mail_shell_sidebar_get_folder_tree (mail_shell_sidebar);
-	folder_uri = em_folder_tree_get_selected_uri (folder_tree);
 
-	if (folder_uri != NULL) {
-		EMailBackend *backend;
-		EMailSession *session;
-		CamelStore *store;
-		gchar *folder_name;
-		gboolean success;
-
-		backend = E_MAIL_BACKEND (shell_backend);
-		session = e_mail_backend_get_session (backend);
-
-		success = e_mail_folder_uri_parse (
-			CAMEL_SESSION (session), folder_uri,
-			&store, &folder_name, NULL);
+	if (em_folder_tree_get_selected (folder_tree, &store, &folder_name)) {
 
 		/* FIXME This blocks and is not cancellable. */
-		if (success) {
-			folder = camel_store_get_folder_sync (
-				store, folder_name, 0, NULL, NULL);
-			g_object_unref (store);
-			g_free (folder_name);
-		}
+		folder = camel_store_get_folder_sync (
+			store, folder_name, 0, NULL, NULL);
 
-		g_free (folder_uri);
+		g_object_unref (store);
+		g_free (folder_name);
 	}
 
 exit:
@@ -235,7 +219,6 @@ mail_shell_backend_sync_store_done_cb (CamelStore *store,
 
 static void
 mail_shell_backend_sync_store_cb (CamelStore *store,
-                                  const gchar *display_name,
                                   EMailShellBackend *mail_shell_backend)
 {
 	mail_shell_backend->priv->mail_sync_in_progress++;
@@ -251,6 +234,8 @@ mail_shell_backend_mail_sync (EMailShellBackend *mail_shell_backend)
 {
 	EShell *shell;
 	EShellBackend *shell_backend;
+	EMailBackend *backend;
+	EMailSession *session;
 
 	shell_backend = E_SHELL_BACKEND (mail_shell_backend);
 	shell = e_shell_backend_get_shell (shell_backend);
@@ -263,8 +248,11 @@ mail_shell_backend_mail_sync (EMailShellBackend *mail_shell_backend)
 	if (mail_shell_backend->priv->mail_sync_in_progress)
 		goto exit;
 
+	backend = E_MAIL_BACKEND (mail_shell_backend);
+	session = e_mail_backend_get_session (backend);
+
 	e_mail_store_foreach (
-		(GHFunc) mail_shell_backend_sync_store_cb,
+		session, (GFunc) mail_shell_backend_sync_store_cb,
 		mail_shell_backend);
 
 exit:
@@ -342,6 +330,11 @@ mail_shell_backend_window_created_cb (EShell *shell,
 	}
 
 	if (E_IS_MSG_COMPOSER (window)) {
+		/* Start the mail backend if it isn't already.  This
+		 * may be necessary when opening a new composer window
+		 * from a shell view other than mail. */
+		e_shell_backend_start (shell_backend);
+
 		/* Integrate the new composer into the mail module. */
 		em_configure_new_composer (E_MSG_COMPOSER (window));
 		return;
@@ -716,7 +709,8 @@ e_mail_labels_get_filter_options (void)
 
 /* utility functions for mbox importer */
 static void
-mbox_create_preview_cb (GObject *preview, GtkWidget **preview_widget)
+mbox_create_preview_cb (GObject *preview,
+                        GtkWidget **preview_widget)
 {
 	EMFormatHTMLDisplay *format;
 	EWebView *web_view;
@@ -733,7 +727,8 @@ mbox_create_preview_cb (GObject *preview, GtkWidget **preview_widget)
 }
 
 static void
-mbox_fill_preview_cb (GObject *preview, CamelMimeMessage *msg)
+mbox_fill_preview_cb (GObject *preview,
+                      CamelMimeMessage *msg)
 {
 	EMFormatHTMLDisplay *format;
 
