@@ -27,7 +27,6 @@
 
 #include "e-mail-config-hook.h"
 #include "e-mail-event-hook.h"
-#include "e-mail-junk-hook.h"
 
 #include "e-mail-shell-backend.h"
 #include "e-mail-shell-content.h"
@@ -52,7 +51,6 @@ e_module_load (GTypeModule *type_module)
 
 	e_mail_config_hook_register_type (type_module);
 	e_mail_event_hook_register_type (type_module);
-	e_mail_junk_hook_register_type (type_module);
 
 	e_mail_shell_backend_register_type (type_module);
 	e_mail_shell_content_register_type (type_module);
