@@ -103,8 +103,8 @@ void org_credativ_evolution_readpst_cancel (EImport *ei, EImportTarget *target,
 gint e_plugin_lib_enable (EPlugin *ep, gint enable);
 
 /* em-folder-selection-button.h is private, even though other internal evo plugins use it!
-   so declare the functions here
-   TODO: sort out whether this should really be private
+ * so declare the functions here
+ * TODO: sort out whether this should really be private
 */
 
 static guchar pst_signature[] = { '!', 'B', 'D', 'N' };
@@ -141,7 +141,8 @@ struct _PstImporter {
 };
 
 gboolean
-org_credativ_evolution_readpst_supported (EPlugin *epl, EImportTarget *target)
+org_credativ_evolution_readpst_supported (EPlugin *epl,
+                                          EImportTarget *target)
 {
 	gchar signature[sizeof (pst_signature)];
 	gboolean ret = FALSE;
@@ -177,37 +178,43 @@ org_credativ_evolution_readpst_supported (EPlugin *epl, EImportTarget *target)
 }
 
 static void
-checkbox_mail_toggle_cb (GtkToggleButton *tb, EImportTarget *target)
+checkbox_mail_toggle_cb (GtkToggleButton *tb,
+                         EImportTarget *target)
 {
 	g_datalist_set_data (&target->data, "pst-do-mail", GINT_TO_POINTER (gtk_toggle_button_get_active (tb)));
 }
 
 static void
-checkbox_addr_toggle_cb (GtkToggleButton *tb, EImportTarget *target)
+checkbox_addr_toggle_cb (GtkToggleButton *tb,
+                         EImportTarget *target)
 {
 	g_datalist_set_data (&target->data, "pst-do-addr", GINT_TO_POINTER (gtk_toggle_button_get_active (tb)));
 }
 
 static void
-checkbox_appt_toggle_cb (GtkToggleButton *tb, EImportTarget *target)
+checkbox_appt_toggle_cb (GtkToggleButton *tb,
+                         EImportTarget *target)
 {
 	g_datalist_set_data (&target->data, "pst-do-appt", GINT_TO_POINTER (gtk_toggle_button_get_active (tb)));
 }
 
 static void
-checkbox_task_toggle_cb (GtkToggleButton *tb, EImportTarget *target)
+checkbox_task_toggle_cb (GtkToggleButton *tb,
+                         EImportTarget *target)
 {
 	g_datalist_set_data (&target->data, "pst-do-task", GINT_TO_POINTER (gtk_toggle_button_get_active (tb)));
 }
 
 static void
-checkbox_journal_toggle_cb (GtkToggleButton *tb, EImportTarget *target)
+checkbox_journal_toggle_cb (GtkToggleButton *tb,
+                            EImportTarget *target)
 {
 	g_datalist_set_data (&target->data, "pst-do-journal", GINT_TO_POINTER (gtk_toggle_button_get_active (tb)));
 }
 
 static void
-folder_selected (EMFolderSelectionButton *button, EImportTargetURI *target)
+folder_selected (EMFolderSelectionButton *button,
+                 EImportTargetURI *target)
 {
 	g_free (target->uri_dest);
 	target->uri_dest = g_strdup (em_folder_selection_button_get_folder_uri (button));
@@ -276,12 +283,12 @@ get_suggested_foldername (EImportTargetURI *target)
 
 	if (!foldername) {
 		/* Suggest a folder that is in the same mail storage as the users' inbox,
-		   with a name derived from the .PST file */
+		 * with a name derived from the .PST file */
 		inbox = e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_INBOX);
 
 		delim = g_strrstr (inbox, "#");
 		if (delim != NULL) {
-			foldername = g_string_new_len (inbox, delim-inbox);
+			foldername = g_string_new_len (inbox, delim - inbox);
 		} else {
 			foldername = g_string_new (inbox);
 		}
@@ -317,7 +324,7 @@ get_suggested_foldername (EImportTargetURI *target)
 		gint i, len;
 		len = foldername->len;
 
-		for (i=1; i<10000; i++) {
+		for (i = 1; i < 10000; i++) {
 			g_string_truncate (foldername, len);
 			g_string_append_printf (foldername, "_%d", i);
 			/* FIXME Not passing a GCancellable or GError here. */
@@ -338,7 +345,8 @@ get_suggested_foldername (EImportTargetURI *target)
 }
 
 static void
-widget_sanitizer_cb (GtkToggleButton *button, GtkWidget *source_combo)
+widget_sanitizer_cb (GtkToggleButton *button,
+                     GtkWidget *source_combo)
 {
 	g_return_if_fail (button != NULL);
 	g_return_if_fail (source_combo != NULL);
@@ -372,7 +380,12 @@ get_source_combo_key (EClientSourceType source_type)
 }
 
 static void
-add_source_list_with_check (GtkWidget *frame, const gchar *caption, EClientSourceType source_type, GCallback toggle_callback, EImportTarget *target)
+add_source_list_with_check (GtkWidget *frame,
+                            const gchar *caption,
+                            EClientSourceType source_type,
+                            GCallback toggle_callback,
+                            EImportTarget *target,
+			    gboolean active)
 {
 	GtkWidget *check, *hbox;
 	ESourceList *source_list = NULL;
@@ -385,7 +398,7 @@ add_source_list_with_check (GtkWidget *frame, const gchar *caption, EClientSourc
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 
 	check = gtk_check_button_new_with_mnemonic (caption);
-	gtk_toggle_button_set_active ((GtkToggleButton *) check, FALSE);
+	gtk_toggle_button_set_active ((GtkToggleButton *) check, active);
 	g_signal_connect (check, "toggled", toggle_callback, target);
 	gtk_box_pack_start ((GtkBox *) hbox, check, FALSE, FALSE, 0);
 
@@ -415,26 +428,111 @@ add_source_list_with_check (GtkWidget *frame, const gchar *caption, EClientSourc
 	}
 }
 
+static void
+pst_import_check_items (EImportTarget *target)
+{
+	gboolean has_mail = FALSE, has_addr = FALSE, has_appt = FALSE, has_task = FALSE, has_journal = FALSE;
+	gchar *filename;
+	pst_file pst;
+	pst_item *item = NULL, *subitem;
+	pst_desc_tree *d_ptr, *topitem;
+
+	filename = g_filename_from_uri (((EImportTargetURI *) target)->uri_src, NULL, NULL);
+
+	if (pst_init (&pst, filename) < 0) {
+		goto end;
+	}
+
+	if ((item = pst_parse_item (&pst, pst.d_head, NULL)) == NULL) {
+		goto end;
+	}
+
+	if ((topitem = pst_getTopOfFolders (&pst, item)) == NULL) {
+		goto end;
+	}
+
+	d_ptr = topitem->child;
+
+	/* Walk through folder tree */
+	while (d_ptr != NULL && (!has_mail || !has_addr || !has_appt || !has_task || !has_journal)) {
+		subitem = pst_parse_item (&pst, d_ptr, NULL);
+
+		if (subitem != NULL &&
+		    subitem->message_store == NULL &&
+		    subitem->folder == NULL) {
+			switch (subitem->type) {
+			case PST_TYPE_CONTACT:
+				if (subitem->contact)
+					has_addr = TRUE;
+				break;
+			case PST_TYPE_APPOINTMENT:
+				if (subitem->appointment)
+					has_appt = TRUE;
+				break;
+			case PST_TYPE_TASK:
+				if (subitem->appointment)
+					has_task = TRUE;
+				break;
+			case PST_TYPE_JOURNAL:
+				if (subitem->appointment)
+					has_journal = TRUE;
+				break;
+			case PST_TYPE_NOTE:
+			case PST_TYPE_SCHEDULE:
+			case PST_TYPE_REPORT:
+				if (subitem->email)
+					has_mail = TRUE;
+				break;
+			}
+		}
+
+		pst_freeItem (subitem);
+
+		if (d_ptr->child != NULL) {
+			d_ptr = d_ptr->child;
+		} else if (d_ptr->next != NULL) {
+			d_ptr = d_ptr->next;
+		} else {
+			while (d_ptr != topitem && d_ptr->next == NULL) {
+				d_ptr = d_ptr->parent;
+			}
+
+			if (d_ptr == topitem)
+				break;
+
+			d_ptr = d_ptr->next;
+		}
+	}
+
+	pst_freeItem (item);
+
+ end:
+	g_free (filename);
+	g_datalist_set_data (&target->data, "pst-do-mail", GINT_TO_POINTER (has_mail));
+	g_datalist_set_data (&target->data, "pst-do-addr", GINT_TO_POINTER (has_addr));
+	g_datalist_set_data (&target->data, "pst-do-appt", GINT_TO_POINTER (has_appt));
+	g_datalist_set_data (&target->data, "pst-do-task", GINT_TO_POINTER (has_task));
+	g_datalist_set_data (&target->data, "pst-do-journal", GINT_TO_POINTER (has_journal));
+}
+
 GtkWidget *
-org_credativ_evolution_readpst_getwidget (EImport *ei, EImportTarget *target, EImportImporter *im)
+org_credativ_evolution_readpst_getwidget (EImport *ei,
+                                          EImportTarget *target,
+                                          EImportImporter *im)
 {
 	EShell *shell;
 	EShellBackend *shell_backend;
 	GtkWidget *hbox, *framebox, *w, *check;
 	gchar *foldername;
 
-	g_datalist_set_data (&target->data, "pst-do-mail", GINT_TO_POINTER (TRUE));
-	g_datalist_set_data (&target->data, "pst-do-addr", GINT_TO_POINTER (FALSE));
-	g_datalist_set_data (&target->data, "pst-do-appt", GINT_TO_POINTER (FALSE));
-	g_datalist_set_data (&target->data, "pst-do-task", GINT_TO_POINTER (FALSE));
-	g_datalist_set_data (&target->data, "pst-do-journal", GINT_TO_POINTER (FALSE));
+	pst_import_check_items (target);
 
 	framebox = gtk_vbox_new (FALSE, 2);
 
 	/* Mail */
 	hbox = gtk_hbox_new (FALSE, 0);
 	check = gtk_check_button_new_with_mnemonic (_("_Mail"));
-	gtk_toggle_button_set_active ((GtkToggleButton *) check, TRUE);
+	gtk_toggle_button_set_active ((GtkToggleButton *) check, GPOINTER_TO_INT (g_datalist_get_data (&target->data, "pst-do-mail")));
 	g_signal_connect (check, "toggled", G_CALLBACK (checkbox_mail_toggle_cb), target);
 	gtk_box_pack_start ((GtkBox *) hbox, check, FALSE, FALSE, 0);
 
@@ -458,10 +556,14 @@ org_credativ_evolution_readpst_getwidget (EImport *ei, EImportTarget *target, EI
 
 	gtk_box_pack_start ((GtkBox *) framebox, hbox, FALSE, FALSE, 0);
 
-	add_source_list_with_check (framebox, _("_Address Book"), E_CLIENT_SOURCE_TYPE_CONTACTS, G_CALLBACK (checkbox_addr_toggle_cb), target);
-	add_source_list_with_check (framebox, _("A_ppointments"), E_CLIENT_SOURCE_TYPE_EVENTS, G_CALLBACK (checkbox_appt_toggle_cb), target);
-	add_source_list_with_check (framebox, _("_Tasks"), E_CLIENT_SOURCE_TYPE_TASKS, G_CALLBACK (checkbox_task_toggle_cb), target);
-	add_source_list_with_check (framebox, _("_Journal entries"), E_CLIENT_SOURCE_TYPE_MEMOS, G_CALLBACK (checkbox_journal_toggle_cb), target);
+	add_source_list_with_check (framebox, _("_Address Book"), E_CLIENT_SOURCE_TYPE_CONTACTS, G_CALLBACK (checkbox_addr_toggle_cb), target,
+		GPOINTER_TO_INT (g_datalist_get_data (&target->data, "pst-do-addr")));
+	add_source_list_with_check (framebox, _("A_ppointments"), E_CLIENT_SOURCE_TYPE_EVENTS, G_CALLBACK (checkbox_appt_toggle_cb), target,
+		GPOINTER_TO_INT (g_datalist_get_data (&target->data, "pst-do-appt")));
+	add_source_list_with_check (framebox, _("_Tasks"), E_CLIENT_SOURCE_TYPE_TASKS, G_CALLBACK (checkbox_task_toggle_cb), target,
+		GPOINTER_TO_INT (g_datalist_get_data (&target->data, "pst-do-task")));
+	add_source_list_with_check (framebox, _("_Journal entries"), E_CLIENT_SOURCE_TYPE_MEMOS, G_CALLBACK (checkbox_journal_toggle_cb), target,
+		GPOINTER_TO_INT (g_datalist_get_data (&target->data, "pst-do-journal")));
 
 	gtk_widget_show_all (framebox);
 
@@ -471,7 +573,9 @@ org_credativ_evolution_readpst_getwidget (EImport *ei, EImportTarget *target, EI
 }
 
 static void
-client_opened_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+client_opened_cb (GObject *source_object,
+                  GAsyncResult *result,
+                  gpointer user_data)
 {
 	PstImporter *m = user_data;
 	GError *error = NULL;
@@ -520,7 +624,8 @@ client_opened_cb (GObject *source_object, GAsyncResult *result, gpointer user_da
 }
 
 static void
-open_client (PstImporter *m, EClientSourceType source_type)
+open_client (PstImporter *m,
+             EClientSourceType source_type)
 {
 	ESourceComboBox *combo;
 	ESource *source;
@@ -562,7 +667,8 @@ pst_prepare_run (PstImporter *m)
 }
 
 static gchar *
-pst_import_describe (PstImporter *m, gint complete)
+pst_import_describe (PstImporter *m,
+                     gint complete)
 {
 	return g_strdup (_("Importing Outlook data"));
 }
@@ -576,7 +682,8 @@ pst_import_import (PstImporter *m,
 }
 
 static void
-count_items (PstImporter *m, pst_desc_tree *topitem)
+count_items (PstImporter *m,
+             pst_desc_tree *topitem)
 {
 	pst_desc_tree *d_ptr;
 
@@ -671,7 +778,8 @@ pst_import_file (PstImporter *m)
 }
 
 static void
-pst_import_folders (PstImporter *m, pst_desc_tree *topitem)
+pst_import_folders (PstImporter *m,
+                    pst_desc_tree *topitem)
 {
 	CamelOperation *co = CAMEL_OPERATION (m->cancellable);
 	GHashTable *node_to_folderuri; /* pointers of hierarchy nodes, to them associated folder uris */
@@ -744,7 +852,9 @@ pst_import_folders (PstImporter *m, pst_desc_tree *topitem)
 }
 
 static void
-pst_process_item (PstImporter *m, pst_desc_tree *d_ptr, gchar **previous_folder)
+pst_process_item (PstImporter *m,
+                  pst_desc_tree *d_ptr,
+                  gchar **previous_folder)
 {
 	pst_item *item = NULL;
 
@@ -851,7 +961,8 @@ foldername_to_utf8 (const gchar *pstname)
 }
 
 static void
-pst_process_folder (PstImporter *m, pst_item *item)
+pst_process_folder (PstImporter *m,
+                    pst_item *item)
 {
 	gchar *uri;
 	g_free (m->folder_name);
@@ -951,7 +1062,8 @@ pst_create_folder (PstImporter *m)
  * Returns: #CamelMimePart containing data and mime type
  */
 static CamelMimePart *
-attachment_to_part (PstImporter *m, pst_item_attach *attach)
+attachment_to_part (PstImporter *m,
+                    pst_item_attach *attach)
 {
 	CamelMimePart *part;
 	const gchar *mimetype;
@@ -986,7 +1098,8 @@ attachment_to_part (PstImporter *m, pst_item_attach *attach)
 }
 
 static void
-pst_process_email (PstImporter *m, pst_item *item)
+pst_process_email (PstImporter *m,
+                   pst_item *item)
 {
 	CamelMimeMessage *msg;
 	CamelInternetAddress *addr;
@@ -1222,7 +1335,9 @@ pst_process_email (PstImporter *m, pst_item *item)
 }
 
 static void
-contact_set_string (EContact *contact, EContactField id, gchar *string)
+contact_set_string (EContact *contact,
+                    EContactField id,
+                    gchar *string)
 {
 	if (string != NULL) {
 		e_contact_set (contact, id, string);
@@ -1230,7 +1345,10 @@ contact_set_string (EContact *contact, EContactField id, gchar *string)
 }
 
 static void
-unknown_field (EContact *contact, GString *notes, const gchar *name, gchar *string)
+unknown_field (EContact *contact,
+               GString *notes,
+               const gchar *name,
+               gchar *string)
 {
 	/* Field could not be mapped directly so add to notes field */
 	if (string != NULL) {
@@ -1239,7 +1357,15 @@ unknown_field (EContact *contact, GString *notes, const gchar *name, gchar *stri
 }
 
 static void
-contact_set_address (EContact *contact, EContactField id, gchar *address, gchar *city, gchar *country, gchar *po_box, gchar *postal_code, gchar *state, gchar *street)
+contact_set_address (EContact *contact,
+                     EContactField id,
+                     gchar *address,
+                     gchar *city,
+                     gchar *country,
+                     gchar *po_box,
+                     gchar *postal_code,
+                     gchar *state,
+                     gchar *street)
 {
 	EContactAddress *eaddress;
 
@@ -1275,7 +1401,9 @@ contact_set_address (EContact *contact, EContactField id, gchar *address, gchar
 }
 
 void
-contact_set_date (EContact *contact, EContactField id, FILETIME *date)
+contact_set_date (EContact *contact,
+                  EContactField id,
+                  FILETIME *date)
 {
 	if (date && (date->dwLowDateTime || date->dwHighDateTime) ) {
 		time_t t1;
@@ -1295,7 +1423,8 @@ contact_set_date (EContact *contact, EContactField id, FILETIME *date)
 }
 
 static void
-pst_process_contact (PstImporter *m, pst_item *item)
+pst_process_contact (PstImporter *m,
+                     pst_item *item)
 {
 	pst_item_contact *c;
 	EContact *ec;
@@ -1462,7 +1591,8 @@ pst_process_contact (PstImporter *m, pst_item *item)
  * Returns: converted date
  */
 struct icaltimetype
-get_ical_date (FILETIME *date, gboolean is_date)
+get_ical_date (FILETIME *date,
+               gboolean is_date)
 {
 	if (date && (date->dwLowDateTime || date->dwHighDateTime) ) {
 		time_t t;
@@ -1475,7 +1605,10 @@ get_ical_date (FILETIME *date, gboolean is_date)
 }
 
 static void
-set_cal_attachments (ECalClient *cal, ECalComponent *ec, PstImporter *m, pst_item_attach *attach)
+set_cal_attachments (ECalClient *cal,
+                     ECalComponent *ec,
+                     PstImporter *m,
+                     pst_item_attach *attach)
 {
 	GSList *list = NULL;
 	const gchar *uid;
@@ -1572,7 +1705,10 @@ set_cal_attachments (ECalClient *cal, ECalComponent *ec, PstImporter *m, pst_ite
 }
 
 static void
-fill_calcomponent (PstImporter *m, pst_item *item, ECalComponent *ec, const gchar *type)
+fill_calcomponent (PstImporter *m,
+                   pst_item *item,
+                   ECalComponent *ec,
+                   const gchar *type)
 {
 	pst_item_appointment *a;
 	pst_item_email *e;
@@ -1683,7 +1819,7 @@ fill_calcomponent (PstImporter *m, pst_item *item, ECalComponent *ec, const gcha
 
 		if (a->alarm_minutes) {
 			trigger.type = E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_START;
-			trigger.u.rel_duration = icaldurationtype_from_int (- (a->alarm_minutes)*60);
+			trigger.u.rel_duration = icaldurationtype_from_int (- (a->alarm_minutes) * 60);
 			e_cal_component_alarm_set_trigger (alarm, trigger);
 		}
 
@@ -1773,7 +1909,11 @@ fill_calcomponent (PstImporter *m, pst_item *item, ECalComponent *ec, const gcha
 }
 
 static void
-pst_process_component (PstImporter *m, pst_item *item, const gchar *comp_type, ECalClient *cal)
+pst_process_component (PstImporter *m,
+                       pst_item *item,
+                       const gchar *comp_type,
+		       ECalComponentVType vtype,
+                       ECalClient *cal)
 {
 	ECalComponent *ec;
 	gchar *uid = NULL;
@@ -1782,7 +1922,7 @@ pst_process_component (PstImporter *m, pst_item *item, const gchar *comp_type, E
 	g_return_if_fail (item->appointment != NULL);
 
 	ec = e_cal_component_new ();
-	e_cal_component_set_new_vtype (ec, E_CAL_COMPONENT_EVENT);
+	e_cal_component_set_new_vtype (ec, vtype);
 
 	fill_calcomponent (m, item, ec, comp_type);
 	set_cal_attachments (cal, ec, m, item->attach);
@@ -1799,26 +1939,30 @@ pst_process_component (PstImporter *m, pst_item *item, const gchar *comp_type, E
 }
 
 static void
-pst_process_appointment (PstImporter *m, pst_item *item)
+pst_process_appointment (PstImporter *m,
+                         pst_item *item)
 {
-	pst_process_component (m, item, "appointment", m->calendar);
+	pst_process_component (m, item, "appointment", E_CAL_COMPONENT_EVENT, m->calendar);
 }
 
 static void
-pst_process_task (PstImporter *m, pst_item *item)
+pst_process_task (PstImporter *m,
+                  pst_item *item)
 {
-	pst_process_component (m, item, "task", m->tasks);
+	pst_process_component (m, item, "task", E_CAL_COMPONENT_TODO, m->tasks);
 }
 
 static void
-pst_process_journal (PstImporter *m, pst_item *item)
+pst_process_journal (PstImporter *m,
+                     pst_item *item)
 {
-	pst_process_component (m, item, "journal", m->journal);
+	pst_process_component (m, item, "journal", E_CAL_COMPONENT_JOURNAL, m->journal);
 }
 
 /* Print an error message - maybe later bring up an error dialog? */
 static void
-pst_error_msg (const gchar *fmt, ...)
+pst_error_msg (const gchar *fmt,
+               ...)
 {
 	va_list ap;
 
@@ -1889,7 +2033,10 @@ pst_status_timeout (gpointer data)
 }
 
 static void
-pst_status (CamelOperation *op, const gchar *what, gint pc, gpointer data)
+pst_status (CamelOperation *op,
+            const gchar *what,
+            gint pc,
+            gpointer data)
 {
 	PstImporter *importer = data;
 
@@ -1901,7 +2048,8 @@ pst_status (CamelOperation *op, const gchar *what, gint pc, gpointer data)
 }
 
 static void
-pst_import (EImport *ei, EImportTarget *target)
+pst_import (EImport *ei,
+            EImportTarget *target)
 {
 	PstImporter *m;
 
@@ -1934,7 +2082,9 @@ pst_import (EImport *ei, EImportTarget *target)
 
 /* Start the main import operation */
 void
-org_credativ_evolution_readpst_import (EImport *ei, EImportTarget *target, EImportImporter *im)
+org_credativ_evolution_readpst_import (EImport *ei,
+                                       EImportTarget *target,
+                                       EImportImporter *im)
 {
 	if (GPOINTER_TO_INT (g_datalist_get_data (&target->data, "pst-do-mail"))
 	    || GPOINTER_TO_INT (g_datalist_get_data (&target->data, "pst-do-addr"))
@@ -1948,7 +2098,9 @@ org_credativ_evolution_readpst_import (EImport *ei, EImportTarget *target, EImpo
 }
 
 void
-org_credativ_evolution_readpst_cancel (EImport *ei, EImportTarget *target, EImportImporter *im)
+org_credativ_evolution_readpst_cancel (EImport *ei,
+                                       EImportTarget *target,
+                                       EImportImporter *im)
 {
 	PstImporter *m = g_datalist_get_data (&target->data, "pst-msg");
 
@@ -1958,7 +2110,8 @@ org_credativ_evolution_readpst_cancel (EImport *ei, EImportTarget *target, EImpo
 }
 
 gint
-e_plugin_lib_enable (EPlugin *ep, gint enable)
+e_plugin_lib_enable (EPlugin *ep,
+                     gint enable)
 {
 	return 0;
 }
@@ -1973,7 +2126,8 @@ e_plugin_lib_enable (EPlugin *ep, gint enable)
  * Returns: 0 for sucess, -1 for failure
  */
 gint
-pst_init (pst_file *pst, gchar *filename)
+pst_init (pst_file *pst,
+          gchar *filename)
 {
 
 #if 0
@@ -2013,7 +2167,8 @@ pst_init (pst_file *pst, gchar *filename)
  * or %NULL if error
  */
 gchar *
-get_pst_rootname (pst_file *pst, gchar *filename)
+get_pst_rootname (pst_file *pst,
+                  gchar *filename)
 {
 	pst_item *item = NULL;
 	gchar *rootname = NULL;
