@@ -21,7 +21,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <glib/gi18n.h>
 #include "e-util/e-util.h"
@@ -29,10 +31,6 @@
 #include "gal-view-etable.h"
 #include "gal-view-factory-etable.h"
 
-#define GAL_VIEW_FACTORY_ETABLE_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), GAL_TYPE_VIEW_FACTORY_ETABLE, GalViewFactoryEtablePrivate))
-
 struct _GalViewFactoryEtablePrivate {
 	ETableSpecification *specification;
 };
@@ -96,7 +94,7 @@ view_factory_etable_dispose (GObject *object)
 {
 	GalViewFactoryEtablePrivate *priv;
 
-	priv = GAL_VIEW_FACTORY_ETABLE_GET_PRIVATE (object);
+	priv = GAL_VIEW_FACTORY_ETABLE (object)->priv;
 
 	if (priv->specification != NULL) {
 		g_object_unref (priv->specification);
@@ -125,7 +123,7 @@ view_factory_etable_new_view (GalViewFactory *factory,
 {
 	GalViewFactoryEtablePrivate *priv;
 
-	priv = GAL_VIEW_FACTORY_ETABLE_GET_PRIVATE (factory);
+	priv = GAL_VIEW_FACTORY_ETABLE (factory)->priv;
 
 	return gal_view_etable_new (priv->specification, name);
 }
@@ -163,7 +161,9 @@ gal_view_factory_etable_class_init (GalViewFactoryEtableClass *class)
 static void
 gal_view_factory_etable_init (GalViewFactoryEtable *factory)
 {
-	factory->priv = GAL_VIEW_FACTORY_ETABLE_GET_PRIVATE (factory);
+	factory->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		factory, GAL_TYPE_VIEW_FACTORY_ETABLE,
+		GalViewFactoryEtablePrivate);
 }
 
 /**
