@@ -31,17 +31,18 @@
 
 G_BEGIN_DECLS
 
-ETableHeader *e_table_state_to_header                    (GtkWidget           *widget,
-							  ETableHeader        *full_header,
-							  ETableState         *state);
+ETableHeader *	e_table_state_to_header		(GtkWidget *widget,
+						 ETableHeader *full_header,
+						 ETableState *state);
 
-ETableHeader *e_table_spec_to_full_header                (ETableSpecification *spec,
-							  ETableExtras        *ete);
+ETableHeader *	e_table_spec_to_full_header	(ETableSpecification *spec,
+						 ETableExtras *ete);
 
-ETableCol    *e_table_util_calculate_current_search_col  (ETableHeader        *header,
-							  ETableHeader        *full_header,
-							  ETableSortInfo      *sort_info,
-							  gboolean             always_search);
+ETableCol *	e_table_util_calculate_current_search_col
+						(ETableHeader *header,
+						 ETableHeader *full_header,
+						 ETableSortInfo *sort_info,
+						 gboolean always_search);
 
 G_END_DECLS
 
