@@ -775,6 +775,7 @@ e_text_set_property (GObject *object,
 			      (color.green & 0xff00) << 8 |
 			      (color.blue & 0xff00) |
 			      0xff);
+		text->rgba_set = TRUE;
 		text->needs_redraw = 1;
 		needs_update = 1;
 		break;
@@ -789,6 +790,7 @@ e_text_set_property (GObject *object,
 			      (color.green & 0xff00) << 8 |
 			      (color.blue & 0xff00) |
 			      0xff);
+		text->rgba_set = TRUE;
 		text->needs_redraw = 1;
 		needs_update = 1;
 		break;
@@ -798,6 +800,7 @@ e_text_set_property (GObject *object,
 		color.red = ((text->rgba >> 24) & 0xff) * 0x101;
 		color.green = ((text->rgba >> 16) & 0xff) * 0x101;
 		color.blue = ((text->rgba >> 8) & 0xff) * 0x101;
+		text->rgba_set = TRUE;
 		text->needs_redraw = 1;
 		needs_update = 1;
 		break;
@@ -1310,7 +1313,7 @@ e_text_draw (GnomeCanvasItem *item,
 
 	cairo_save (cr);
 
-	if (text->draw_background || text->draw_button) {
+	if (text->draw_background || text->draw_button || !text->rgba_set) {
 		gdk_cairo_set_source_color (cr, &style->fg[state]);
 	} else {
 		cairo_set_source_rgba (cr,
@@ -3502,6 +3505,7 @@ e_text_init (EText *text)
 	text->im_context_signals_registered = FALSE;
 
 	text->handle_popup            = FALSE;
+	text->rgba_set		      = FALSE;
 
 	e_canvas_item_set_reflow_callback (GNOME_CANVAS_ITEM (text), e_text_reflow);
 }
